@@ -1,4 +1,4 @@
-# Random Utilities That I Find Useful
+# RUTIFU - Random Utilities That I Find Useful
 
 import syslog
 import os
@@ -17,8 +17,8 @@ except ImportError:
 
 # log a message to syslog or stdout
 def log(*args):
-    message = args[0]+" "   # first argument is the object doing the logging
-    for arg in args[1:]:
+    message = ""
+    for arg in args:
         message += arg.__str__()+" "
     if sysLogging:
         syslog.syslog(message)
@@ -32,6 +32,11 @@ def logException(name, ex):
     for tracebackLine in tracebackLines:
         log(tracebackLine)
 
+# log a debug message conditioned on a specified global variable
+def debug(*args):
+    if (args[0] in globals()) and globals()[args[0]]:  # only log if the specified debug variable is True
+        log(*args[1:])
+
 # thread object that logs a stack trace if there is an uncaught exception
 class LogThread(threading.Thread):
     def __init__(self, **kwargs):
@@ -50,14 +55,8 @@ def startThread(name, target, **kwargs):
     thread = LogThread(name=name, target=target, **kwargs)
     thread.start()
 
-# log a debug message conditioned on a specified global variable
-def debug(*args):
-    if (args[0] in globals()) and globals()[args[0]]:  # only log if the specified debug variable is True
-        log(*args[1:])
-
 # execute an external OS command
 def osCommand(cmd):
-    debug("debugOsCmd", "cmd:", cmd)
     try:
         executor.execute(cmd)
     except Exception as ex:
